@@ -1,3 +1,17 @@
+"""
+ffmpeg_streaming.rep
+~~~~~~~~~~~~
+
+Generate Representation object
+
+
+:copyright: (c) 2019 by Amin Yazdanpanah.
+:website: https://www.aminyazdanpanah.com
+:email: contact@aminyazdanpanah.com
+:license: MIT, see LICENSE for more details.
+"""
+
+
 class Representation:
     def __init__(self, **kwargs):
         self.width = kwargs.pop('width', None)
